@@ -161,26 +161,26 @@ private void
 	
 private string
 SIGSUB[] = {
-	"unknown(sub 0)",
-	"unknown(sub 1)",
+	"reserved(sub 0)",
+	"reserved(sub 1)",
 	"signature creation time(sub 2)",
 	"signature expiration time(sub 3)",
 	"exportable certification(sub 4)",
 	"trust signature(sub 5)", 
 	"regular expression(sub 6)",
 	"revocable(sub 7)",
-	"unknown(sub 8)",
+	"reserved(sub 8)",
 	"key expiration time(sub 9)",
 	"additional decryption key(sub 10) WARNING: see CA-2000-18!!!",
 	"preferred symmetric algorithms(sub 11)", 
 	"revocation key(sub 12)", 
-	"unknown(sub 13)",
-	"unknown(sub 14)",
-	"unknown(sub 15)",
+	"reserved(sub 13)",
+	"reserved(sub 14)",
+	"reserved(sub 15)",
 	"issuer key ID(sub 16)", 
-	"unknown(sub 17)",
-	"unknown(sub 18)",
-	"unknown(sub 19)",
+	"reserved(sub 17)",
+	"reserved(sub 18)",
+	"reserved(sub 19)",
 	"notation data(sub 20)",
 	"preferred hash algorithms(sub 21)",
 	"preferred compression algorithms(sub 22)",
@@ -193,7 +193,7 @@ SIGSUB[] = {
 	"reason for revocation(sub 29)",
         "features(sub 30)",
         "signature target(sub 31)",
-	"embedded signature(sub 32",
+	"embedded signature(sub 32)",
 };
 #define SIGSUB_NUM (sizeof(SIGSUB) / sizeof(string))
 
